@@ -8,6 +8,7 @@ import (
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"golang.org/x/sync/errgroup"
@@ -359,14 +360,58 @@ func TestInvalidAlgorithm(t *testing.T) {
 	require.Empty(t, sum)
 }
 
-func TestExtraOr(t *testing.T) {
-	a := &Artifact{
+func TestExtra(t *testing.T) {
+	a := Artifact{
 		Extra: map[string]interface{}{
 			"Foo": "foo",
+			"docker": config.Docker{
+				ID:  "id",
+				Use: "docker",
+			},
+			"fail-plz": config.Homebrew{
+				Plist: "aaaa",
+			},
+			"unsupported": func() {},
+			"binaries":    []string{"foo", "bar"},
 		},
 	}
-	require.Equal(t, "foo", a.ExtraOr("Foo", "bar"))
-	require.Equal(t, "bar", a.ExtraOr("Foobar", "bar"))
+
+	t.Run("string", func(t *testing.T) {
+		foo, err := Extra[string](a, "Foo")
+		require.NoError(t, err)
+		require.Equal(t, "foo", foo)
+		require.Equal(t, "foo", ExtraOr(a, "Foo", "bar"))
+	})
+
+	t.Run("missing field", func(t *testing.T) {
+		bar, err := Extra[string](a, "Foobar")
+		require.NoError(t, err)
+		require.Equal(t, "", bar)
+		require.Equal(t, "bar", ExtraOr(a, "Foobar", "bar"))
+	})
+
+	t.Run("complex", func(t *testing.T) {
+		docker, err := Extra[config.Docker](a, "docker")
+		require.NoError(t, err)
+		require.Equal(t, "id", docker.ID)
+	})
+
+	t.Run("array", func(t *testing.T) {
+		binaries, err := Extra[[]string](a, "binaries")
+		require.NoError(t, err)
+		require.Equal(t, []string{"foo", "bar"}, binaries)
+		require.Equal(t, []string{"foo", "bar"}, ExtraOr(a, "binaries", []string{}))
+	})
+
+	t.Run("unmarshal error", func(t *testing.T) {
+		_, err := Extra[config.Docker](a, "fail-plz")
+		require.EqualError(t, err, "json: unknown field \"Name\"")
+	})
+
+	t.Run("marshal error", func(t *testing.T) {
+		_, err := Extra[config.Docker](a, "unsupported")
+		require.EqualError(t, err, "json: unsupported type: func()")
+	})
 }
 
 func TestByIDs(t *testing.T) {
@@ -483,46 +528,6 @@ func TestByFormats(t *testing.T) {
 	require.Len(t, artifacts.Filter(ByFormats("zip", "tar.gz")).items, 3)
 }
 
-func TestTypeToString(t *testing.T) {
-	for _, a := range []Type{
-		UploadableArchive,
-		UploadableBinary,
-		UploadableFile,
-		Binary,
-		UniversalBinary,
-		LinuxPackage,
-		PublishableSnapcraft,
-		Snapcraft,
-		PublishableDockerImage,
-		DockerImage,
-		DockerManifest,
-		Checksum,
-		Signature,
-		Certificate,
-		UploadableSourceArchive,
-		BrewTap,
-		GoFishRig,
-		KrewPluginManifest,
-		ScoopManifest,
-		SBOM,
-		PkgBuild,
-		SrcInfo,
-	} {
-		t.Run(a.String(), func(t *testing.T) {
-			require.NotEqual(t, "unknown", a.String())
-			bts, err := a.MarshalJSON()
-			require.NoError(t, err)
-			require.Equal(t, []byte(`"`+a.String()+`"`), bts)
-		})
-	}
-	t.Run("unknown", func(t *testing.T) {
-		require.Equal(t, "unknown", Type(9999).String())
-		bts, err := Type(9999).MarshalJSON()
-		require.NoError(t, err)
-		require.Equal(t, []byte(`"unknown"`), bts)
-	})
-}
-
 func TestPaths(t *testing.T) {
 	paths := []string{"a/b", "b/c", "d/e", "f/g"}
 	artifacts := New()
@@ -548,15 +553,6 @@ func TestRefresher(t *testing.T) {
 				},
 			},
 		})
-		artifacts.Add(&Artifact{
-			Name: "invalid",
-			Type: Checksum,
-			Extra: map[string]interface{}{
-				"Refresh": func() {
-					t.Fatalf("should not have been called")
-				},
-			},
-		})
 		artifacts.Add(&Artifact{
 			Name: "no refresh",
 			Type: Checksum,
@@ -900,7 +896,11 @@ func Test_ByBinaryLikeArtifacts(t *testing.T) {
 				arts.Add(a)
 			}
 			actual := arts.Filter(ByBinaryLikeArtifacts(arts)).List()
-			assert.Equal(t, tt.expected, actual)
+			expected := New()
+			for _, a := range tt.expected {
+				expected.Add(a)
+			}
+			assert.Equal(t, expected.List(), actual)
 
 			if t.Failed() {
 				t.Log("expected:")
