@@ -12,7 +12,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/apex/log"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/builders/buildtarget"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
@@ -206,11 +206,12 @@ func withOverrides(ctx *context.Context, build config.Build, options api.Options
 				Flags:    build.BuildDetails.Flags,
 				Asmflags: build.BuildDetails.Asmflags,
 				Gcflags:  build.BuildDetails.Gcflags,
+				Env:      build.BuildDetails.Env,
 			}
 			if err := mergo.Merge(&dets, o.BuildDetails, mergo.WithOverride); err != nil {
 				return build.BuildDetails, err
 			}
-			log.WithField("dets", dets).Info("will use")
+			log.WithField("details", dets).Infof("overridden build details for %s", optsTarget)
 			return dets, nil
 		}
 	}
