@@ -6,7 +6,7 @@ import (
 	"os"
 	"time"
 
-	"github.com/apex/log"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/extrafiles"
@@ -48,51 +48,18 @@ func (Pipe) Default(ctx *context.Context) error {
 
 	switch ctx.TokenType {
 	case context.TokenTypeGitLab:
-		if ctx.Config.Release.GitLab.Name == "" {
-			repo, err := getRepository(ctx)
-			if err != nil {
-				return err
-			}
-			ctx.Config.Release.GitLab = repo
+		if err := setupGitLab(ctx); err != nil {
+			return err
 		}
-		ctx.ReleaseURL = fmt.Sprintf(
-			"%s/%s/%s/-/releases/%s",
-			ctx.Config.GitLabURLs.Download,
-			ctx.Config.Release.GitLab.Owner,
-			ctx.Config.Release.GitLab.Name,
-			ctx.Git.CurrentTag,
-		)
 	case context.TokenTypeGitea:
-		if ctx.Config.Release.Gitea.Name == "" {
-			repo, err := getRepository(ctx)
-			if err != nil {
-				return err
-			}
-			ctx.Config.Release.Gitea = repo
+		if err := setupGitea(ctx); err != nil {
+			return err
 		}
-		ctx.ReleaseURL = fmt.Sprintf(
-			"%s/%s/%s/releases/tag/%s",
-			ctx.Config.GiteaURLs.Download,
-			ctx.Config.Release.Gitea.Owner,
-			ctx.Config.Release.Gitea.Name,
-			ctx.Git.CurrentTag,
-		)
 	default:
 		// We keep github as default for now
-		if ctx.Config.Release.GitHub.Name == "" {
-			repo, err := getRepository(ctx)
-			if err != nil && !ctx.Snapshot {
-				return err
-			}
-			ctx.Config.Release.GitHub = repo
+		if err := setupGitHub(ctx); err != nil {
+			return err
 		}
-		ctx.ReleaseURL = fmt.Sprintf(
-			"%s/%s/%s/releases/tag/%s",
-			ctx.Config.GitHubURLs.Download,
-			ctx.Config.Release.GitHub.Owner,
-			ctx.Config.Release.GitHub.Name,
-			ctx.Git.CurrentTag,
-		)
 	}
 
 	// Check if we have to check the git tag for an indicator to mark as pre release
